@@ -38,15 +38,20 @@ var (
 	// commonCommands are the commands that are deemed "common" and shown first
 	// in the CLI help output.
 	commonCommands = []string{
+		"login",
 		"build",
 		"deploy",
 		"release",
+		"status",
 		"up",
 	}
 
 	// hiddenCommands are not shown in CLI help output.
 	hiddenCommands = map[string]struct{}{
 		"plugin": {},
+
+		// Deprecated:
+		"token": {}, // replaced by "user"
 	}
 
 	ExposeDocs bool
@@ -159,6 +164,12 @@ func Commands(
 
 	// start building our commands
 	commands := map[string]cli.CommandFactory{
+		"login": func() (cli.Command, error) {
+			return &LoginCommand{
+				baseCommand: baseCommand,
+			}, nil
+		},
+
 		"init": func() (cli.Command, error) {
 			return &InitCommand{
 				baseCommand: baseCommand,
@@ -326,6 +337,11 @@ func Commands(
 				baseCommand: baseCommand,
 			}, nil
 		},
+		"status": func() (cli.Command, error) {
+			return &StatusCommand{
+				baseCommand: baseCommand,
+			}, nil
+		},
 		"plugin": func() (cli.Command, error) {
 			return &PluginCommand{
 				baseCommand: baseCommand,
@@ -476,6 +492,75 @@ func Commands(
 				baseCommand: baseCommand,
 			}, nil
 		},
+
+		"auth-method": func() (cli.Command, error) {
+			return &helpCommand{
+				SynopsisText: helpText["auth-method"][0],
+				HelpText:     helpText["auth-method"][1],
+			}, nil
+		},
+
+		"auth-method set": func() (cli.Command, error) {
+			return &helpCommand{
+				SynopsisText: helpText["auth-method-set"][0],
+				HelpText:     helpText["auth-method-set"][1],
+			}, nil
+		},
+
+		"auth-method set oidc": func() (cli.Command, error) {
+			return &AuthMethodSetOIDCCommand{
+				baseCommand: baseCommand,
+			}, nil
+		},
+
+		"auth-method inspect": func() (cli.Command, error) {
+			return &AuthMethodInspectCommand{
+				baseCommand: baseCommand,
+			}, nil
+		},
+
+		"auth-method delete": func() (cli.Command, error) {
+			return &AuthMethodDeleteCommand{
+				baseCommand: baseCommand,
+			}, nil
+		},
+
+		"auth-method list": func() (cli.Command, error) {
+			return &AuthMethodListCommand{
+				baseCommand: baseCommand,
+			}, nil
+		},
+
+		"user": func() (cli.Command, error) {
+			return &helpCommand{
+				SynopsisText: helpText["user"][0],
+				HelpText:     helpText["user"][1],
+			}, nil
+		},
+
+		"user inspect": func() (cli.Command, error) {
+			return &UserInspectCommand{
+				baseCommand: baseCommand,
+			}, nil
+		},
+
+		"user modify": func() (cli.Command, error) {
+			return &UserModifyCommand{
+				baseCommand: baseCommand,
+			}, nil
+		},
+
+		"user invite": func() (cli.Command, error) {
+			return &UserInviteCommand{
+				baseCommand: baseCommand,
+			}, nil
+		},
+
+		"user token": func() (cli.Command, error) {
+			return &UserTokenCommand{
+				baseCommand: baseCommand,
+			}, nil
+		},
 	}
 
 	// register our aliases
@@ -683,6 +768,30 @@ Waypoint will search for artifacts to pass to the deployment phase.
 `,
 	},
 
+	"auth-method": {
+		"Auth Method Management",
+		`
+Auth Method Management
+
+The auth-method commands can be used to manage how users can authenticate
+into the Waypoint server. For day-to-day Waypoint users, you likely want
+to use the "waypoint login" command or "waypoint user" commands. The
+auth-method subcommand is primarily aimed at Waypoint server operators.
+`,
+	},
+
+	"auth-method-set": {
+		"Create or update an auth method",
+		`
+Create or update an auth method.
+
+This command can be used to configure a new auth method or update
+an existing auth method. Use the specific auth-method type subcommand.
+Once the auth method is created it is immediately available for use by
+end users.
+`,
+	},
+
 	"config": {
 		"Application configuration management",
 		`
@@ -737,7 +846,7 @@ For more information see: https://waypointproject.io/docs/url
 		`
 Project management.
 
-Projects are comprised of one or more applications. A project maps 
+Projects are comprised of one or more applications. A project maps
 to a VCS repository (if one exists).
 `,
 	},
@@ -773,6 +882,21 @@ Authenticate and invite collaborators.
 
 Tokens are the primary form of authentication to Waypoint. Everyone who
 accesses a Waypoint server requires a token.
+
+` + warnTokenDeprecated,
+	},
+
+	"user": {
+		"User information and management",
+		`
+View, manage, and invite users.
+
+Everyone who uses Waypoint is represented as a Waypoint user, including
+token authentication. This subcommand can be used to inspect information
+about the currently logged in user, generate new access, and invite new
+users directly into the Waypoint server.
+
+If you are looking to log in to Waypoint, use "waypoint login".
 `,
 	},
 }
