@@ -6,8 +6,10 @@ import (
 	"path/filepath"
 
 	"github.com/hashicorp/hcl/v2"
+	"github.com/hashicorp/hcl/v2/gohcl"
 	"github.com/hashicorp/hcl/v2/hclsimple"
 
+	"github.com/hashicorp/waypoint/internal/config/variables"
 	"github.com/hashicorp/waypoint/internal/pkg/defaults"
 	pb "github.com/hashicorp/waypoint/internal/server/gen"
 )
@@ -18,16 +20,19 @@ type Config struct {
 	ctx      *hcl.EvalContext
 	path     string
 	pathData map[string]string
+
+	InputVariables map[string]*variables.Variable
 }
 
 type hclConfig struct {
-	Project string            `hcl:"project,optional"`
-	Runner  *Runner           `hcl:"runner,block" default:"{}"`
-	Labels  map[string]string `hcl:"labels,optional"`
-	Plugin  []*Plugin         `hcl:"plugin,block"`
-	Config  *genericConfig    `hcl:"config,block"`
-	Apps    []*hclApp         `hcl:"app,block"`
-	Body    hcl.Body          `hcl:",body"`
+	Project   string                   `hcl:"project,optional"`
+	Runner    *Runner                  `hcl:"runner,block" default:"{}"`
+	Labels    map[string]string        `hcl:"labels,optional"`
+	Variables []*variables.HclVariable `hcl:"variable,block"`
+	Plugin    []*Plugin                `hcl:"plugin,block"`
+	Config    *genericConfig           `hcl:"config,block"`
+	Apps      []*hclApp                `hcl:"app,block"`
+	Body      hcl.Body                 `hcl:",body"`
 }
 
 // Runner is the configuration for supporting runners in this project.
@@ -117,6 +122,18 @@ func Load(path string, opts *LoadOptions) (*Config, error) {
 	if err := hclsimple.DecodeFile(path, finalizeContext(ctx), &cfg); err != nil {
 		return nil, err
 	}
+
+	// Decode variable blocks
+	schema, _ := gohcl.ImpliedBodySchema(&hclConfig{})
+	content, diags := cfg.Body.Content(schema)
+	if diags.HasErrors() {
+		return nil, diags
+	}
+	vs, diags := variables.DecodeVariableBlocks(content)
+	if diags.HasErrors() {
+		return nil, diags
+	}
+
 	if err := defaults.Set(&cfg); err != nil {
 		return nil, err
 	}
@@ -132,10 +149,11 @@ func Load(path string, opts *LoadOptions) (*Config, error) {
 	}
 
 	return &Config{
-		hclConfig: cfg,
-		ctx:       ctx,
-		path:      filepath.Dir(path),
-		pathData:  pathData,
+		hclConfig:      cfg,
+		ctx:            ctx,
+		path:           filepath.Dir(path),
+		pathData:       pathData,
+		InputVariables: vs,
 	}, nil
 }
 
