@@ -10,12 +10,14 @@ import (
 	"github.com/hashicorp/go-argmapper"
 	"github.com/hashicorp/go-hclog"
 	"github.com/hashicorp/hcl/v2"
+	"github.com/mitchellh/mapstructure"
 	"github.com/zclconf/go-cty/cty"
 	"google.golang.org/grpc/codes"
 	"google.golang.org/grpc/status"
 
 	"github.com/hashicorp/waypoint-plugin-sdk/component"
 	"github.com/hashicorp/waypoint/internal/config"
+	"github.com/hashicorp/waypoint/internal/plugin"
 	pb "github.com/hashicorp/waypoint/internal/server/gen"
 )
 
@@ -144,6 +146,9 @@ type deployOperation struct {
 
 	// cebToken is the token to set for the deployment to auth
 	cebToken string
+
+	// result is either a component.Deployment or component.DeploymentWithUrl
+	result interface{}
 }
 
 func (op *deployOperation) Close() error {
@@ -228,7 +233,7 @@ func (op *deployOperation) Init(app *App) (proto.Message, error) {
 		}
 	}
 
-	return &pb.Deployment{
+	deployment := &pb.Deployment{
 		Generation:  &pb.Generation{Id: generationId},
 		Application: app.ref,
 		Workspace:   app.workspace,
@@ -238,7 +243,9 @@ func (op *deployOperation) Init(app *App) (proto.Message, error) {
 		State:       pb.Operation_CREATED,
 		HasEntrypointConfig: op.DeploymentConfig != nil &&
 			op.DeploymentConfig.ServerAddr != "",
-	}, nil
+	}
+
+	return deployment, nil
 }
 
 func (op *deployOperation) Hooks(app *App) map[string][]*config.Hook {
@@ -272,8 +279,10 @@ func (op *deployOperation) Upsert(
 			// to long enough that it should be forever.
 			Duration: "87600h", // 10 years
 
-			// This is an entrypoint token specifically for this deployment
-			Entrypoint: &pb.Token_Entrypoint{
+			// This is an entrypoint token specifically for this deployment.
+			// NOTE: we purposely use the old "unused" version here until
+			// we have an account system.
+			UnusedEntrypoint: &pb.Token_Entrypoint{
 				DeploymentId: op.id,
 			},
 		})
@@ -311,14 +320,36 @@ func (op *deployOperation) Do(ctx context.Context, log hclog.Logger, app *App, m
 		return nil, err
 	}
 
-	val, err := app.callDynamicFunc(ctx,
+	baseArgs := op.args()
+
+	// Add an outparameter for declared resources, which will be populated by the dynamic func
+	declaredResourcesResp := &component.DeclaredResourcesResp{}
+	args := append(baseArgs, argmapper.Typed(declaredResourcesResp))
+
+	result, err := app.callDynamicFunc(ctx,
 		log,
 		(*component.Deployment)(nil),
 		op.component,
 		op.component.Value.(component.Platform).DeployFunc(),
-		op.args()...,
+		args...,
 	)
 
+	if err != nil {
+		return nil, err
+	}
+
+	// Convert from the plugin declaredResources to server declaredResources. Should be identical.
+	declaredResources := make([]*pb.DeclaredResource, len(declaredResourcesResp.DeclaredResources))
+	for i, pluginDeclaredResource := range declaredResourcesResp.DeclaredResources {
+		var serverDeclaredResource pb.DeclaredResource
+		if err := mapstructure.Decode(pluginDeclaredResource, &serverDeclaredResource); err != nil {
+			return nil, status.Errorf(codes.Internal, "failed to decode plugin declared resource named %q: %s", pluginDeclaredResource.Name, err)
+		}
+		declaredResources[i] = &serverDeclaredResource
+	}
+
+	deploy.DeclaredResources = declaredResources
+
 	if ep, ok := op.component.Value.(component.Execer); ok && ep.ExecFunc() != nil {
 		log.Debug("detected deployment uses an exec plugin, decorating deployment with info")
 		deploy.HasExecPlugin = true
@@ -332,8 +363,7 @@ func (op *deployOperation) Do(ctx context.Context, log hclog.Logger, app *App, m
 	} else {
 		log.Debug("no logs plugin detected on platform component")
 	}
-
-	return val, err
+	return result, err
 }
 
 // args returns the args we send to the Deploy function call
@@ -345,7 +375,7 @@ func (op *deployOperation) args() []argmapper.Arg {
 		// If we don't do this we will panic so its best to protect against this
 		// anyways.
 		args = append(args,
-			argNamedAny("artifact", op.Push.Artifact.Artifact),
+			plugin.ArgNamedAny("artifact", op.Push.Artifact.Artifact),
 		)
 	}
 
