@@ -4,10 +4,11 @@ import (
 	"context"
 	"sync"
 
-	"github.com/boltdb/bolt"
 	"github.com/hashicorp/go-hclog"
 	wphznpb "github.com/hashicorp/waypoint-hzn/pkg/pb"
+	bolt "go.etcd.io/bbolt"
 
+	wpoidc "github.com/hashicorp/waypoint/internal/auth/oidc"
 	"github.com/hashicorp/waypoint/internal/server"
 	pb "github.com/hashicorp/waypoint/internal/server/gen"
 	"github.com/hashicorp/waypoint/internal/server/singleprocess/state"
@@ -45,12 +46,21 @@ type service struct {
 	// service starts up. When Close is called, we wait on this to ensure
 	// that we fully shut down before returning.
 	bgWg sync.WaitGroup
+
+	// superuser is true if all API actions should act as if a superuser
+	// made them. This is used for local mode only.
+	superuser bool
+
+	// oidcCache is the cache for OIDC providers.
+	oidcCache *wpoidc.ProviderCache
 }
 
 // New returns a Waypoint server implementation that uses BotlDB plus
 // in-memory locks to operate safely.
 func New(opts ...Option) (pb.WaypointServer, error) {
 	var s service
+	s.oidcCache = wpoidc.NewProviderCache()
+
 	var cfg config
 	for _, opt := range opts {
 		if err := opt(&s, &cfg); err != nil {
@@ -140,13 +150,11 @@ func New(opts ...Option) (pb.WaypointServer, error) {
 	// pollableItems is a map of potential items Waypoint can queue a poll for.
 	// Each item should implement the pollHandler interface
 	pollableItems := map[string]pollHandler{
-		"project": &projectPoll{state: s.state},
+		"project":                  &projectPoll{state: s.state},
+		"application_statusreport": &applicationPoll{state: s.state, workspace: "default"},
 	}
 
 	// Start our polling background goroutines.
-	// We currently have one  goroutine that we run in the background that
-	// handles the queue of all polling operations. However, there will be more
-	// pollable items to run jobs against in future iterations.
 	// See the func docs for more info.
 	for pollName, pollItem := range pollableItems {
 		s.bgWg.Add(1)
@@ -170,6 +178,7 @@ func New(opts ...Option) (pb.WaypointServer, error) {
 func (s *service) Close() error {
 	s.bgCtxCancel()
 	s.bgWg.Wait()
+	s.oidcCache.Close()
 	return nil
 }
 
@@ -177,6 +186,7 @@ type config struct {
 	db           *bolt.DB
 	serverConfig *serverconfig.Config
 	log          hclog.Logger
+	superuser    bool
 
 	acceptUrlTerms bool
 }
@@ -207,9 +217,23 @@ func WithLogger(log hclog.Logger) Option {
 	}
 }
 
+// WithSuperuser forces all API actions to behave as if a superuser
+// made them. This is usually turned on for local mode only. There is no
+// option (at the time of writing) to enable this on a network-attached server.
+func WithSuperuser() Option {
+	return func(s *service, cfg *config) error {
+		s.superuser = true
+		return nil
+	}
+}
+
+// WithAcceptURLTerms will set the config to either accept or reject the terms
+// of service for using the URL service. Rejecting the TOS will disable the
+// URL service. Note that the actual rejection does not occur until the
+// waypoint horizon client attempts to register its guest account.
 func WithAcceptURLTerms(accept bool) Option {
 	return func(s *service, cfg *config) error {
-		cfg.acceptUrlTerms = true
+		cfg.acceptUrlTerms = accept
 		return nil
 	}
 }
